==> netCoin_1.1.23.tar.gz: netCoin/inst/www/es.js <==
// texts to translate
var texts = {
    netselection : "Gráfico",
    nodes : "Nodos",
    general: "General",
    links: "Enlaces",
    apply: "Aplicar",
    filter: "Filtrar",
    select: "Seleccionar",
    clear: "Limpiar",
    add: "Añadir",
    simpleadvanced: "Simple/avanzado",
    nodesattributes: "Atributos de nodos",
    linksattributes: "Atributos de enlaces",
    noitemsselected: "Sin items seleccionados",
    alertnonodes: "¡No hay nodos seleccionados! Presiona shift para seleccionar nodos.",
    alertnonodestable: "¡No hay nodos seleccionados en la tabla!",
    repulsion: "Repulsión",
    distance: "Distancia",
    loading: "Cargando...",
    pdfexport: "Exportación PDF",
    svgexport: "Exportación SVG",
    showhidelegend: "Mostrar/ocultar leyenda",
    showhideaxes: "Mostrar/ocultar ejes",
    showhideimages: "Mostrar/ocultar imágenes",
    showhidesidebar: "Mostrar/ocultar control lateral",
    showhidebuttons: "Mostrar/ocultar botones",
    showhidetables: "Mostrar/ocultar tablas",
    stopresume: "Parar/reanudar",
    netheatmap: "Red/mapa de color",
    isolateselection: "Filtrar selección",
    resetfilter: "Quitar filtro",
    selectall: "Seleccionar todos/ninguno",
    selectneighbors: "Añadir vecinos",
    egoNet: "EgoRed",
    expandcollapse: "Expandir/contraer",
    tableselection: "Marcados en la tabla",
    reset: "Reiniciar",
    directional: "Mostrar/ocultar flechas",
    degree: "grado",
    none: "Nada",
    downloadtable: "Descargar tabla",
    total: "Total",
    concoincidences: "Coincidencias condicionales",
    coincidences: "Coincidencias",
    ofsomeone: "de",
    withsomeone: "con",
    incidences: "Incidencias",
    expected: "Esperadas",
    expectedconfidence: "+/- Confianza esperada",
    confidenceinterval: "+/- Intervalo de confianza",
    subjectselect: "Evento",
    Label: "Etiqueta",
    LabelSize: "Tam.Eti.",
    Group: "Grupo",
    Order: "Orden",
    OrderA: "A Orden",
    OrderD: "D Orden",
    Size: "Tamaño",
    Color: "Color",
    Shape: "Forma",
    Legend: "Leyenda",
    Width: "Anchura",
    Weight: "Peso",
    Intensity: "Intensidad",
    Text: "Texto",
    Show: "Mostrar",
    Hide: "Ocultar",
    circle: "Círculo",
    cross: "Cruz",
    diamond: "Diamante",
    square: "Cuadrado",
    "triangle-down": "Triangulo-abajo",
    "triangle-up": "Triangulo-arriba",
    trianglesquare: "Triángulo/cuadrado",
    selectacolorscale: "Selecciona una escala de color para ",
    outof: "de",
    scenarios: "Número de escenarios",
    resetzoom: "Reiniciar zoom",
    removefilter: "Quitar filtro",
    alertrecordheatmap: "El mapa de color no puede ser grabado.",
    speed: "Velocidad"
  };

==> netCoin_1.1.26.tar.gz: netCoin/inst/www/es.js <==
// texts to translate
var texts = {
    netselection : "Gráfico",
    nodes : "Nodos",
    general: "General",
    links: "Enlaces",
    apply: "Aplicar",
    filter: "Filtrar",
    select: "Seleccionar",
    clear: "Limpiar",
    add: "Añadir",
    simpleadvanced: "Simple/avanzado",
    nodesattributes: "Atributos de nodos",
    linksattributes: "Atributos de enlaces",
    noitemsselected: "Sin items seleccionados",
    alertnonodes: "¡No hay nodos seleccionados! Presiona shift para seleccionar nodos.",
    alertnonodestable: "¡No hay nada seleccionado en la tabla!",
    repulsion: "Repulsión",
    distance: "Distancia",
    loading: "Cargando...",
    pdfexport: "Exportación PDF",
    svgexport: "Exportación SVG",
    showhidelegend: "Mostrar/ocultar leyenda",
    showhideaxes: "Mostrar/ocultar ejes",
    showhideimages: "Mostrar/ocultar imágenes",
    showhidesidebar: "Mostrar/ocultar control lateral",
    showhidebuttons: "Mostrar/ocultar botones",
    showhidetables: "Mostrar/ocultar tablas",
    stopresume: "Parar/reanudar",
    netheatmap: "Red/mapa de color",
    isolateselection: "Filtrar selección",
    resetfilter: "Quitar filtro",
    selectall: "Seleccionar todos/ninguno",
    selectneighbors: "Añadir vecinos",
    egoNet: "EgoRed",
    expandcollapse: "Expandir/contraer",
    tableselection: "Marcados en la tabla",
    reset: "Reiniciar",
    directional: "Mostrar/ocultar flechas",
    degree: "grado",
    none: "Nada",
    downloadtable: "Descargar tabla",
    total: "Total",
    concoincidences: "Coincidencias condicionales",
    coincidences: "Coincidencias",
    ofsomeone: "de",
    withsomeone: "con",
    incidences: "Incidencias",
    expected: "Esperadas",
    expectedconfidence: "+/- Confianza esperada",
    confidenceinterval: "+/- Intervalo de confianza",
    subjectselect: "Evento",
    Label: "Etiqueta",
    LabelSize: "Tam.Eti.",
    Group: "Grupo",
    Order: "Orden",
    OrderA: "A Orden",
    OrderD: "D Orden",
    Size: "Tamaño",
    Color: "Color",
    Shape: "Forma",
    Legend: "Leyenda",
    Width: "Anchura",
    Weight: "Peso",
    Intensity: "Intensidad",
    Text: "Texto",
    Show: "Mostrar",
    Hide: "Ocultar",
    circle: "Círculo",
    cross: "Cruz",
    diamond: "Diamante",
    square: "Cuadrado",
    "triangle-down": "Triangulo-abajo",
    "triangle-up": "Triangulo-arriba",
    trianglesquare: "Triángulo/cuadrado",
    selectacolorscale: "Selecciona una escala de color para ",
    outof: "de",
    scenarios: "Número de escenarios",
    resetzoom: "Reiniciar zoom",
    removefilter: "Quitar filtro",
    alertrecordheatmap: "El mapa de color no puede ser grabado.",
    speed: "Velocidad"
  };
